@@ -4,11 +4,13 @@ namespace map. Element tree discards all prefixes when parsing the file.
 It is used by the different parsing modules.
 """
 import xml.etree.ElementTree as ET
+from io import StringIO
 
 
-def parse_file(path: str) -> ET:
+def parse_file(file: str or StringIO) -> ET.ElementTree:
     """
     Parses a file, returns the Root element with an attribute 'ns_map' containing the prefix - namespaces map
+    :param file: either the file path (str) or a file-like object
     @return:
     """
     events = "start", "start-ns", "end-ns"
@@ -16,7 +18,7 @@ def parse_file(path: str) -> ET:
     root = None
     ns_map = []
 
-    for event, elem in ET.iterparse(path, events):
+    for event, elem in ET.iterparse(file, events):
         if event == "start-ns":
             ns_map.append(elem)
         elif event == "end-ns":
